@@ -48,15 +48,17 @@
 #define IUCLC	0
 #endif
 #else
+#ifdef HAVE_LOCKDEV
 #include <lockdev.h>
 #endif
+#endif
 
 using namespace std;
 using namespace PLATFORM;
 
 inline bool RemoveLock(const char *strDeviceName)
 {
-  #if !defined(__APPLE__) && !defined(__FreeBSD__)
+  #if !defined(__APPLE__) && !defined(__FreeBSD__) && defined(HAVE_LOCKDEV)
   return dev_unlock(strDeviceName, 0) == 0;
   #else
   void *tmp = (void*)strDeviceName; // silence unused warning
@@ -125,7 +127,7 @@ bool CSerialSocket::Open(uint64_t iTimeoutMs /* = 0 */)
     return false;
   }
 
-  #if !defined(__APPLE__) && !defined(__FreeBSD__)
+  #if !defined(__APPLE__) && !defined(__FreeBSD__) && defined(HAVE_LOCKDEV)
   if (dev_lock(m_strName.c_str()) != 0)
   {
     m_strError = "Couldn't lock the serial port";
